diff --git a/gnu/packages/backup.scm b/gnu/packages/backup.scm
index 0d03d2e87f..4a8385cd68 100644
--- a/gnu/packages/backup.scm
+++ b/gnu/packages/backup.scm
@@ -54,52 +54,59 @@ (define-module (gnu packages backup)
   #:use-module (guix build-system python)
   #:use-module (guix build-system qt)
   #:use-module (gnu packages)
-  #:use-module (gnu packages acl)
-  #:use-module (gnu packages autotools)
-  #:use-module (gnu packages bash)
-  #:use-module (gnu packages base)
-  #:use-module (gnu packages check)
-  #:use-module (gnu packages compression)
-  #:use-module (gnu packages crypto)
-  #:use-module (gnu packages databases)
-  #:use-module (gnu packages datastructures)
-  #:use-module (gnu packages digest)
-  #:use-module (gnu packages dbm)
-  #:use-module (gnu packages dejagnu)
-  #:use-module (gnu packages ftp)
-  #:use-module (gnu packages gettext)
-  #:use-module (gnu packages glib)
-  #:use-module (gnu packages gnupg)
-  #:use-module (gnu packages golang)
-  #:use-module (gnu packages gperf)
-  #:use-module (gnu packages gtk)
-  #:use-module (gnu packages guile)
-  #:use-module (gnu packages guile-xyz)
-  #:use-module (gnu packages linux)
-  #:use-module (gnu packages mcrypt)
-  #:use-module (gnu packages ncurses)
-  #:use-module (gnu packages nettle)
-  #:use-module (gnu packages networking)
-  #:use-module (gnu packages onc-rpc)
-  #:use-module (gnu packages pcre)
-  #:use-module (gnu packages perl)
-  #:use-module (gnu packages pkg-config)
-  #:use-module (gnu packages protobuf)
-  #:use-module (gnu packages python)
-  #:use-module (gnu packages python-build)
-  #:use-module (gnu packages python-check)
-  #:use-module (gnu packages python-crypto)
-  #:use-module (gnu packages python-web)
-  #:use-module (gnu packages python-xyz)
-  #:use-module (gnu packages qt)
-  #:use-module (gnu packages rsync)
-  #:use-module (gnu packages ruby)
-  #:use-module (gnu packages serialization)
-  #:use-module (gnu packages ssh)
-  #:use-module (gnu packages time)
-  #:use-module (gnu packages tls)
-  #:use-module (gnu packages valgrind)
-  #:use-module (gnu packages xml))
+  #:autoload (gnu packages acl) (acl)
+  #:use-module (gnu packages autotools) ; required by "guix build -d guix"
+  #:autoload (gnu packages bash) (bash-minimal)
+  #:autoload (gnu packages base) (coreutils findutils tar tzdata-for-tests)
+  #:autoload (gnu packages check)
+  (check python-flexmock python-mock python-pytest python-pytest-cov
+         python-pytest-mock python-pytest-runner)
+  #:use-module (gnu packages compression) ; required by "guix build -d guix"
+  #:autoload (gnu packages databases) (tdb python-peewee)
+  #:autoload (gnu packages datastructures) (uthash)
+  #:autoload (gnu packages digest) (xxhash)
+  #:autoload (gnu packages dbm) (bdb gdbm)
+  #:autoload (gnu packages dejagnu) (dejagnu)
+  #:autoload (gnu packages ftp) (lftp)
+  #:autoload (gnu packages gettext) (gettext-minimal)
+  #:autoload (gnu packages glib) (dbus glib intltool python-pygobject)
+  #:use-module (gnu packages gnupg) ; required by "guix build -d guix"
+  #:autoload (gnu packages gperf) (gperf-3.0)
+  #:autoload (gnu packages gtk) (gtk+)
+  #:use-module (gnu packages guile) ; required by "guix build -d guix"
+  #:use-module (gnu packages guile-xyz) ; required by "guix build -d guix"
+  #:autoload (gnu packages linux)
+  (btrfs-progs e2fsprogs fuse ntfs-3g util-linux)
+  #:autoload (gnu packages mcrypt) (mcrypt)
+  #:autoload (gnu packages ncurses) (ncurses)
+  #:use-module (gnu packages nettle) ; required by "guix build -d guix"
+  #:autoload (gnu packages networking) (mbuffer)
+  #:autoload (gnu packages onc-rpc) (libtirpc rpcsvc-proto)
+  #:autoload (gnu packages pcre) (pcre)
+  #:autoload (gnu packages perl)
+  (perl perl-libtime-parsedate perl-libtime-period)
+  #:use-module (gnu packages pkg-config) ; required by "guix build -d guix"
+  #:autoload (gnu packages protobuf) (protobuf)
+  #:autoload (gnu packages python) (python)
+  #:autoload (gnu packages python-build) (python-setuptools-scm)
+  #:autoload (gnu packages python-check) (python-pytest-qt)
+  #:autoload (gnu packages python-crypto)
+  (python-keyring python-paramiko python-secretstorage)
+  #:autoload (gnu packages python-web)
+  (python-requests python-urllib3)
+  #:autoload (gnu packages python-xyz)
+  (python-appdirs python-colorama python-cython python-fasteners python-future
+                  python-jsonschema python-llfuse python-lockfile
+                  python-msgpack-1.0.2 python-pexpect python-psutil
+                  python-setuptools-git)
+  #:autoload (gnu packages qt) (python-pyqt-without-qtwebkit qtsvg-5)
+  #:autoload (gnu packages rsync) (librsync librsync-0.9 rsync)
+  #:autoload (gnu packages ruby) (ruby-asciidoctor)
+  #:autoload (gnu packages serialization) (python-ruamel.yaml)
+  #:autoload (gnu packages ssh) (openssh)
+  #:autoload (gnu packages time) (python-dateutil)
+  #:autoload (gnu packages tls) (gnutls libressl openssl)
+  #:use-module (gnu packages xml)) ; required by "guix build -d guix"
 
 (define-public duplicity
   (package
